import{a0 as t,r as a,o as s,c as d}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5ad87a08-9089-4c24-a8df-7aa4f538d714",e._sentryDebugIdIdentifier="sentry-dbid-5ad87a08-9089-4c24-a8df-7aa4f538d714")}catch{}})();const r={};function c(e,o){const n=a("RouterView");return s(),d(n,{class:"router"})}const f=t(r,[["render",c],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.5c6a1d41.js.map
