import{d as n,o as s,Y as d,a,$ as r,ed as l,a0 as c}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="16cdc133-3daf-4001-8390-e241f26f5482",e._sentryDebugIdIdentifier="sentry-dbid-16cdc133-3daf-4001-8390-e241f26f5482")}catch{}})();const _={class:"content-layout"},f=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",_,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=c(f,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.f92ff80c.js.map
