import{d as t,o as d,Y as o,b as s,u as r,by as _,a0 as c}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f9ead8d2-9e06-4aa3-a983-a07c1d2a2134",e._sentryDebugIdIdentifier="sentry-dbid-f9ead8d2-9e06-4aa3-a983-a07c1d2a2134")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(a,n)=>(d(),o("div",i,[s(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.23bc0e74.js.map
