import{O as r}from"./workspaceStore.e47060bf.js";import{d as l,X as i,o as u,Y as c,b as a,w as o,u as d,aG as n,dd as f,dc as b}from"./index.d0f12294.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d8ed110e-a5a7-4fc9-b3e7-bd87b7fe4a47",e._sentryDebugIdIdentifier="sentry-dbid-d8ed110e-a5a7-4fc9-b3e7-bd87b7fe4a47")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(d(f),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(d(b),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.d58f4b22.js.map
