import{d as i,o as p,c as a,w as n,b as m,u as t}from"./index.d0f12294.js";import"./editor.95f16260.js";import{W as s}from"./workspaces.e43325e2.js";import{C as d}from"./ContentLayout.f92ff80c.js";import{_ as c,E as f}from"./View.vue_vue_type_script_setup_true_lang.1a7d99da.js";import"./workspaceStore.e47060bf.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";import"./asyncComputed.703c33fd.js";import"./record.8c284c67.js";import"./gateway.ae1d6857.js";import"./popupNotifcation.a0a6244b.js";import"./fetch.e5ebd511.js";import"./SaveButton.a02cacb0.js";import"./UnsavedChangesHandler.d2f6de7c.js";import"./ExclamationCircleOutlined.c4fbd42a.js";import"./CrudView.423d8744.js";import"./router.375df57e.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d6f2b20e.js";import"./BookOutlined.7c922f07.js";import"./PhDotsThreeVertical.vue.d0b16f96.js";import"./Badge.f6241be2.js";import"./index.a82e0ed1.js";import"./polling.c979afd7.js";import"./PhPencil.vue.7418c4e5.js";import"./index.289665f1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7a7584c4-a0ea-4983-9e38-c2054ba11ac8",o._sentryDebugIdIdentifier="sentry-dbid-7a7584c4-a0ea-4983-9e38-c2054ba11ac8")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(p(),a(d,null,{default:n(()=>[m(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.1c2c38a0.js.map
