import{O as r}from"./workspaceStore.e47060bf.js";import{d as i,X as l,o as c,Y as f,b as a,w as n,u as o,aG as s,dd as u,dc as b}from"./index.d0f12294.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8fde3a8e-b1c5-48a1-bf31-11f9c2b9f507",e._sentryDebugIdIdentifier="sentry-dbid-8fde3a8e-b1c5-48a1-bf31-11f9c2b9f507")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,d)=>(c(),f("div",null,[a(o(u),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.a316324b.js.map
