import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.1a7d99da.js";import{d as a,ea as i,o as s,c as m,u as d}from"./index.d0f12294.js";import"./gateway.ae1d6857.js";import"./popupNotifcation.a0a6244b.js";import"./fetch.e5ebd511.js";import"./record.8c284c67.js";import"./SaveButton.a02cacb0.js";import"./UnsavedChangesHandler.d2f6de7c.js";import"./ExclamationCircleOutlined.c4fbd42a.js";import"./CrudView.423d8744.js";import"./router.375df57e.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d6f2b20e.js";import"./BookOutlined.7c922f07.js";import"./url.121c9984.js";import"./PhDotsThreeVertical.vue.d0b16f96.js";import"./Badge.f6241be2.js";import"./index.a82e0ed1.js";import"./asyncComputed.703c33fd.js";import"./polling.c979afd7.js";import"./PhPencil.vue.7418c4e5.js";import"./index.289665f1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="aed3443d-8a53-4446-91aa-61860edfab82",o._sentryDebugIdIdentifier="sentry-dbid-aed3443d-8a53-4446-91aa-61860edfab82")}catch{}})();const z=a({__name:"EnvVars",setup(o){const e=i().params.projectId,t=new p(e);return(c,f)=>(s(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.53c4f0a6.js.map
