import{_ as d}from"./Login.vue_vue_type_script_setup_true_lang.9976d09a.js";import{d as f,eo as _,ea as m,o as l,Y as b,b as y,u as c,a0 as g}from"./index.d0f12294.js";import{u as w}from"./workspaceStore.e47060bf.js";import"./Logo.8f27935a.js";import"./string.d9c83adf.js";import"./CircularLoading.13413fc4.js";import"./index.c7e8afe7.js";import"./index.289665f1.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fff011b6-1922-4525-949b-308413e1906b",e._sentryDebugIdIdentifier="sentry-dbid-fff011b6-1922-4525-949b-308413e1906b")}catch{}})();const k={class:"runner"},h=f({__name:"Login",setup(e){const o=_(),r=m(),n=w(),i=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var a,p,u;return l(),b("div",k,[y(d,{"logo-url":(p=(a=c(n).state.workspace)==null?void 0:a.logoUrl)!=null?p:void 0,"brand-name":(u=c(n).state.workspace)==null?void 0:u.brandName,onDone:i},null,8,["logo-url","brand-name"])])}}});const S=g(h,[["__scopeId","data-v-a7e3f7bf"]]);export{S as default};
//# sourceMappingURL=Login.fc60d0fc.js.map
