import{b as a,ee as u,ei as c}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6ed8671b-b240-40ad-8a03-778503b5cbe7",e._sentryDebugIdIdentifier="sentry-dbid-6ed8671b-b240-40ad-8a03-778503b5cbe7")}catch{}})();function o(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){d(e,i,r[i])})}return e}function d(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var l=function(t,r){var n=o({},t,r.attrs);return a(u,o({},n,{icon:c}),null)};l.displayName="CloseCircleOutlined";l.inheritAttrs=!1;const f=l;export{f as C};
//# sourceMappingURL=CloseCircleOutlined.c0e3f3e1.js.map
