import{P as k}from"./api.8656aeba.js";import{b as _}from"./workspaceStore.e47060bf.js";import{d as w,N as g,O as d,e as v,o as r,Y as h,b as s,w as T,u as e,c as p,S as m,a0 as K}from"./index.d0f12294.js";import{K as S,_ as I,W as P,P as R,b as V}from"./WorkflowView.0114ce29.js";import{A as c,T as x}from"./TabPane.79f4882f.js";import"./Card.2a8fe028.js";import"./fetch.e5ebd511.js";import"./metadata.bc77f4b9.js";import"./PhBug.vue.33662d9e.js";import"./PhCheckCircle.vue.e567d5b0.js";import"./PhKanban.vue.fc0591cb.js";import"./PhWebhooksLogo.vue.15a28437.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";import"./polling.c979afd7.js";import"./asyncComputed.703c33fd.js";import"./PhQuestion.vue.f82af3dd.js";import"./ant-design.d89b18ab.js";import"./index.a82e0ed1.js";import"./index.3814eba6.js";import"./index.05dd3c22.js";import"./CollapsePanel.40b6e69e.js";import"./index.a552d580.js";import"./index.7c84a9f5.js";import"./Badge.f6241be2.js";import"./PhArrowCounterClockwise.vue.70f7f135.js";import"./Workflow.1ecea04a.js";import"./validations.2475f715.js";import"./string.d9c83adf.js";import"./uuid.f9389d59.js";import"./index.c7e8afe7.js";import"./workspaces.e43325e2.js";import"./record.8c284c67.js";import"./index.61f90e53.js";import"./PhArrowDown.vue.1c758684.js";import"./LoadingOutlined.bcfc8c20.js";import"./DeleteOutlined.5a680b6a.js";import"./PhDownloadSimple.vue.07a1756e.js";import"./utils.537da94d.js";import"./LoadingContainer.23bc0e74.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="6bd4265c-7406-483e-9674-b41fc5dcae94",t._sentryDebugIdIdentifier="sentry-dbid-6bd4265c-7406-483e-9674-b41fc5dcae94")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const a=_().authHeaders,b=new k(a),i=new R(a),u=new V(a),y=new g(d.array(d.string()),"kanban-selected-stages"),o=v("kanban");return(B,l)=>(r(),h("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=f=>o.value=f)},{default:T(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(r(),p(S,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(r(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(r(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(b)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d6c18c3e"]]);export{ge as default};
//# sourceMappingURL=Threads.2e2a8fc1.js.map
