import{a0 as n,o,Y as d,$ as s,a,S as r}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e95dd75d-956b-40ae-86ab-65f3996da71f",e._sentryDebugIdIdentifier="sentry-dbid-e95dd75d-956b-40ae-86ab-65f3996da71f")}catch{}})();const f={},c={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),d("div",c,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(f,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.52f1acec.js.map
