import{d as r,o as d,c as o,w as a,b as f,$ as b,u as s,dh as u,ey as i,eB as l,bT as c}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b8b23621-f4d0-4bbc-b261-5a77aa309dfb",e._sentryDebugIdIdentifier="sentry-dbid-b8b23621-f4d0-4bbc-b261-5a77aa309dfb")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,n)=>(d(),o(s(c),i(l(t.$attrs)),{default:a(()=>[f(s(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[b(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.7c4b948d.js.map
