import{U as c,dA as i,dB as d}from"./index.d0f12294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="1c9317f5-b600-4217-bb0a-7441ffb48605",e._sentryDebugIdIdentifier="sentry-dbid-1c9317f5-b600-4217-bb0a-7441ffb48605")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:b,QuarterPicker:o,RangePicker:a}=i(d),u=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:b,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{u as D,r as M,o as Q,a as R,t as W};
//# sourceMappingURL=dayjs.9c046fb9.js.map
