import"./App.vue_vue_type_style_index_0_lang.03b90ea7.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.03b90ea7.js";import"./workspaceStore.e47060bf.js";import"./index.d0f12294.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";import"./PlayerConfigProvider.e5e86f58.js";import"./index.c7e8afe7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="50df9bfe-d5ea-4127-9033-36c17c591193",e._sentryDebugIdIdentifier="sentry-dbid-50df9bfe-d5ea-4127-9033-36c17c591193")}catch{}})();export{c as default};
//# sourceMappingURL=App.5afbb284.js.map
