import{E as y}from"./api.8656aeba.js";import{C as c}from"./ContentLayout.f92ff80c.js";import{d as w,N as g,O as b,e as _,o as a,c as i,w as u,b as n,u as o,S as s}from"./index.d0f12294.js";import{K as v,_ as K,W as E,E as R,a as T}from"./WorkflowView.0114ce29.js";import{A as p,T as V}from"./TabPane.79f4882f.js";import"./fetch.e5ebd511.js";import"./metadata.bc77f4b9.js";import"./PhBug.vue.33662d9e.js";import"./PhCheckCircle.vue.e567d5b0.js";import"./PhKanban.vue.fc0591cb.js";import"./PhWebhooksLogo.vue.15a28437.js";import"./polling.c979afd7.js";import"./asyncComputed.703c33fd.js";import"./PhQuestion.vue.f82af3dd.js";import"./ant-design.d89b18ab.js";import"./index.a82e0ed1.js";import"./index.3814eba6.js";import"./index.05dd3c22.js";import"./CollapsePanel.40b6e69e.js";import"./index.a552d580.js";import"./index.7c84a9f5.js";import"./Badge.f6241be2.js";import"./PhArrowCounterClockwise.vue.70f7f135.js";import"./Workflow.1ecea04a.js";import"./validations.2475f715.js";import"./string.d9c83adf.js";import"./uuid.f9389d59.js";import"./index.c7e8afe7.js";import"./workspaces.e43325e2.js";import"./workspaceStore.e47060bf.js";import"./url.121c9984.js";import"./colorHelpers.b079bb04.js";import"./record.8c284c67.js";import"./index.61f90e53.js";import"./PhArrowDown.vue.1c758684.js";import"./Card.2a8fe028.js";import"./LoadingOutlined.bcfc8c20.js";import"./DeleteOutlined.5a680b6a.js";import"./PhDownloadSimple.vue.07a1756e.js";import"./utils.537da94d.js";import"./LoadingContainer.23bc0e74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ec8448a5-4983-47d5-968e-45695c8ac46e",e._sentryDebugIdIdentifier="sentry-dbid-ec8448a5-4983-47d5-968e-45695c8ac46e")}catch{}})();const yo=w({__name:"WorkflowThreads",setup(e){const t=new R,m=new T,f=new g(b.array(b.string()),"kanban-selected-stages"),k=new y,r=_("kanban");return(W,l)=>(a(),i(c,{"full-width":""},{default:u(()=>[n(o(V),{activeKey:r.value,"onUpdate:activeKey":l[0]||(l[0]=d=>r.value=d)},{default:u(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(a(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(f),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(a(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(a(),i(E,{key:2,"kanban-repository":o(t),"workflow-api":o(k)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.55396698.js.map
